==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/KeepCollectionContent.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using j4o.lang;
using j4o.util;
namespace com.db4o.test {

   public class KeepCollectionContent {
      
      public KeepCollectionContent() : base() {
      }
      
      public void store() {
         Tester.deleteAllInstances(new Atom());
         Tester.deleteAllInstances(new System.Collections.Hashtable());
         Tester.deleteAllInstances(new ArrayList());
         System.Collections.Hashtable ht1 = new System.Collections.Hashtable();
         ht1.Add(new Atom(), new Atom());
         Tester.store(ht1);
         ArrayList al1 = new ArrayList();
         al1.Add(new Atom());
         Tester.store(al1);
      }
      
      public void test() {
         Tester.deleteAllInstances(new System.Collections.Hashtable());
         Tester.deleteAllInstances(new ArrayList());
         Tester.ensureOccurrences(new Atom(), 3);
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/KeepCollectionContent.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using j4o.lang;
using j4o.util;
namespace com.db4o.test {

   public class KeepCollectionContent {
      
      public KeepCollectionContent() : base() {
      }
      
      public void Store() {
         Tester.DeleteAllInstances(new Atom());
         Tester.DeleteAllInstances(new System.Collections.Hashtable());
         Tester.DeleteAllInstances(new ArrayList());
         System.Collections.Hashtable ht1 = new System.Collections.Hashtable();
         ht1.Add(new Atom(), new Atom());
         Tester.Store(ht1);
         ArrayList al1 = new ArrayList();
         al1.Add(new Atom());
         Tester.Store(al1);
      }
      
      public void Test() {
         Tester.DeleteAllInstances(new System.Collections.Hashtable());
         Tester.DeleteAllInstances(new ArrayList());
         Tester.EnsureOccurrences(new Atom(), 3);
      }
   }
}
